@@ -1,16 +1,17 @@
 #!/usr/bin/python3
 
 import sys
+
 from debmutate.debhelper import (
     ensure_minimum_debhelper_version,
     read_debhelper_compat_file,
-    )
+)
+
 from lintian_brush.fixer import (
     control,
-    report_result,
     fixed_lintian_tag,
-    )
-
+    report_result,
+)
 
 # Debian source package is not obliged to contain `debian/compat'.
 # Firstly, it may not use debhelper; secondly it may use modern
@@ -18,19 +19,22 @@ from lintian_brush.fixer import (
 
 
 try:
-    minimum_version = read_debhelper_compat_file('debian/compat')
+    minimum_version = read_debhelper_compat_file("debian/compat")
 except FileNotFoundError:
     sys.exit(0)
 
 with control as updater:
     if ensure_minimum_debhelper_version(
-            updater.source, "%s~" % minimum_version):
+        updater.source, f"{minimum_version}~"
+    ):
         fixed_lintian_tag(
-            'source',
-            'no-versioned-debhelper-prerequisite',
-            info='%d' % minimum_version)
+            "source",
+            "no-versioned-debhelper-prerequisite",
+            info="%d" % minimum_version,
+        )
 
 
 report_result(
-    "Bump debhelper dependency to >= %s, since that's what is "
-    "used in debian/compat." % minimum_version)
+    f"Bump debhelper dependency to >= {minimum_version}, since that's what is "
+    "used in debian/compat."
+)
