@@ -7,15 +7,18 @@ try:
 except ModuleNotFoundError:
     sys.exit(2)
 
-from lintian_brush.lintian_overrides import remove_unused
 from lintian_brush.fixer import (
-    control, net_access_allowed, report_result, diligence, fixed_lintian_tag,
-    )
-
+    control,
+    diligence,
+    fixed_lintian_tag,
+    net_access_allowed,
+    report_result,
+)
+from lintian_brush.lintian_overrides import remove_unused
 
 INTERMITTENT_LINTIAN_TAGS = [
-    'rc-version-greater-than-expected-version',
-    ]
+    "rc-version-greater-than-expected-version",
+]
 
 
 if diligence() < 1:
@@ -26,16 +29,19 @@ if not net_access_allowed():
     sys.exit(0)
 
 removed = remove_unused(
-    control.paragraphs, ignore_tags=INTERMITTENT_LINTIAN_TAGS)
+    control.paragraphs, ignore_tags=INTERMITTENT_LINTIAN_TAGS
+)
 
 description = [
-    'Remove %d unused lintian overrides.\n' % len(removed),
-    '\n',
-    ]
+    "Remove %d unused lintian overrides.\n" % len(removed),
+    "\n",
+]
 for override in removed:
-    description.append('* %s\n' % override.tag)
+    description.append(f"* {override.tag}\n")
     fixed_lintian_tag(
-        'source', 'unused-override', info=(
-            override.tag, override.info if override.info else ''))
+        "source",
+        "unused-override",
+        info=(override.tag, override.info if override.info else ""),
+    )
 
-report_result(''.join(description), certainty='certain')
+report_result("".join(description), certainty="certain")
