@@ -381,8 +381,9 @@ fn run_lintian_fixer(
         diligence,
         timestamp,
         basis_tree
-            .map(|bt| Box::new(breezyshim::RevisionTree(bt)) as Box<dyn breezyshim::Tree>)
-            .as_ref(),
+            .map(breezyshim::RevisionTree)
+            .as_ref()
+            .map(|bt| bt as &dyn breezyshim::Tree),
         changes_by,
     )
     .map_err(|e| match e {
@@ -556,7 +557,11 @@ fn update_official_vcs(
         committer,
         force,
     ) {
-        Ok((repo_url, branch, subpath)) => Ok((repo_url.to_string(), branch, subpath)),
+        Ok(parsed_vcs) => Ok((
+            parsed_vcs.repo_url,
+            parsed_vcs.branch,
+            parsed_vcs.subpath.map(Into::into),
+        )),
         Err(PublishError::FileNotFound(p)) => Err(PyFileNotFoundError::new_err((p,))),
         Err(PublishError::NoVcsLocation) => Err(NoVcsLocation::new_err(())),
         Err(PublishError::ConflictingVcsAlreadySpecified(
@@ -581,6 +586,28 @@ fn find_fixers_dir() -> Option<std::path::PathBuf> {
     lintian_brush::find_fixers_dir()
 }
 
+#[pyfunction]
+fn determine_browser_url(
+    vcs_type: &str,
+    vcs_url: &str,
+    net_access: Option<bool>,
+) -> PyResult<Option<String>> {
+    Ok(
+        debian_analyzer::vcs::determine_browser_url(vcs_type, vcs_url, net_access)
+            .map(|u| u.to_string()),
+    )
+}
+
+#[pyfunction]
+fn determine_gitlab_browser_url(url: &str) -> String {
+    debian_analyzer::vcs::determine_gitlab_browser_url(url).to_string()
+}
+
+#[pyfunction]
+fn canonicalize_vcs_browser_url(url: &str) -> String {
+    debian_analyzer::vcs::canonicalize_vcs_browser_url(url).to_string()
+}
+
 #[pymodule]
 fn _lintian_brush_rs(py: Python, m: &PyModule) -> PyResult<()> {
     pyo3_log::init();
@@ -653,6 +680,9 @@ fn _lintian_brush_rs(py: Python, m: &PyModule) -> PyResult<()> {
     m.add_wrapped(wrap_pyfunction!(update_official_vcs))?;
     m.add_wrapped(wrap_pyfunction!(guess_repository_url))?;
     m.add_wrapped(wrap_pyfunction!(default_debianize_cache_dir))?;
+    m.add_wrapped(wrap_pyfunction!(determine_browser_url))?;
+    m.add_wrapped(wrap_pyfunction!(determine_gitlab_browser_url))?;
+    m.add_wrapped(wrap_pyfunction!(canonicalize_vcs_browser_url))?;
     m.add("NoVcsLocation", py.get_type::<NoVcsLocation>())?;
     m.add(
         "ConflictingVcsAlreadySpecified",
