@@ -482,7 +482,7 @@ pub fn apply_multiarch_hints(
     let (changes, _tree_changes, mut specific_files) = match apply_or_revert(
         local_tree,
         subpath,
-        basis_tree.as_ref(),
+        &basis_tree,
         dirty_tracker,
         |path| -> Result<Vec<Change>, ()> {
             let mut changes: Vec<Change> = vec![];
